==> haskell-wl-pprint-annotated-0.1.0.1-253-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-annotated
version:              0.1.0.1
visibility:           public
id:                   wl-pprint-annotated-0.1.0.1-3o4533uijss8UQSSep3DYD
key:                  wl-pprint-annotated-0.1.0.1-3o4533uijss8UQSSep3DYD
license:              BSD-3-Clause
copyright:            2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
stability:            experimental
homepage:             https://github.com/minad/wl-pprint-annotated#readme
synopsis:             Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.

category:             Text
abi:                  d4ed40ee169a9ce03e466161b67d8566
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.WL
hidden-modules:       Paths_wl_pprint_annotated
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-annotated
hs-libraries:         HSwl-pprint-annotated-0.1.0.1-3o4533uijss8UQSSep3DYD
depends:
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-annotated-0.1.0.1-254-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-annotated
version:              0.1.0.1
visibility:           public
id:                   wl-pprint-annotated-0.1.0.1-ITdJZBZjMRfLEI9CDyU1IR
key:                  wl-pprint-annotated-0.1.0.1-ITdJZBZjMRfLEI9CDyU1IR
license:              BSD-3-Clause
copyright:            2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
stability:            experimental
homepage:             https://github.com/minad/wl-pprint-annotated#readme
synopsis:             Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.

category:             Text
abi:                  c33e29a39f755b3f37e327e9fc9bd236
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.WL
hidden-modules:       Paths_wl_pprint_annotated
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-annotated
hs-libraries:         HSwl-pprint-annotated-0.1.0.1-ITdJZBZjMRfLEI9CDyU1IR
depends:
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
